#' @keywords internal
#' @aliases dynatop-package
"_PACKAGE"

#' @import xts
#' @importFrom R6 R6Class
#' @importFrom zoo index
#' @importFrom stats start end aggregate
#' @importFrom Rcpp evalCpp
#' @useDynLib dynatop, .registration=TRUE
NULL
